# BIJ1 flyer app back-end

## Prepare config file

```bash
cp backend/configs/mysql.txt backend/configs/mysql.cnf
```

## Usage

Requirements:
- [Python 3](https://www.python.org/)
- [MySQL](https://www.mysql.com/) / [MariaDB](https://mariadb.org/)

Run the following commands, given a running MySQL:
```bash
# tell django to use the local db
cp backend/configs/mysql.cnf backend/configs/mysql.django.cnf
# populate the database
mysql -uroot --password=password bij1 < /scripts/dump.sql
# create a virtual environment
python3 -m venv ./env
# active the virtual env
source ./env/bin/activate
# install python dependencies
pip install -r requirements.txt
# prepare the database
python manage.py migrate
# create user
python manage.py createsuperuser
# run the application
python manage.py runserver
```

## Usage by Docker

Requirements:
- [Docker](https://docker.com/)

```bash
# tell django to use the docker db
sed 's/127.0.0.1/db/g' backend/configs/mysql.cnf > backend/configs/mysql.django.cnf
# boot the application
docker compose up
# populate the database
docker exec -it $(docker compose ps db --format json | jq '.[].Name' | sed -n 's/"//pg') /bin/bash -c 'mysql -uroot --password=password bij1 < /scripts/dump.sql'
# create user
docker exec -it $(docker compose ps python --format json | jq '.[].Name' | sed -n 's/"//pg') /bin/bash -c 'cd /app; python manage.py createsuperuser'
```

## Data sources

- [amsterdam buurten csv (2021)](https://maps.amsterdam.nl/open_geodata/?k=198)
- [amsterdam geojson](https://maps.amsterdam.nl/open_geodata/geojson_lnglat.php?KAARTLAAG=GEBIED_BUURTEN&THEMA=gebiedsindeling)
