from django.db import models
from django.contrib.auth.models import User


class Department(models.Model):
    _id = models.AutoField(primary_key=True, editable=False)
    name = models.CharField(max_length=200, null=False, blank=False)
    users = models.ManyToManyField(User, through='Role')

    def __str__(self):
        return self.name


class Role(models.Model):
    _id = models.AutoField(primary_key=True, editable=False)
    user = models.ForeignKey(User, on_delete=models.CASCADE, null=False)
    department = models.ForeignKey(Department, on_delete=models.CASCADE, null=False)
    DEPARTMENT_ROLES = (
        (1, 'Administrator'),
        (2, 'Manager'),
        (3, 'User'),
        (4, 'Guest'),
    )
    role = models.CharField(max_length=1, choices=DEPARTMENT_ROLES)


class Province(models.Model):
    _id = models.AutoField(primary_key=True, editable=False)
    name = models.CharField(max_length=200, null=False, blank=False)


class Township(models.Model):
    _id = models.AutoField(primary_key=True, editable=False)
    name = models.CharField(max_length=200, null=False, blank=False)
    province = models.ForeignKey(Province, on_delete=models.CASCADE, null=True, blank=True)

    def __str__(self):
        return self.name


class Neighbourhood(models.Model):
    _id = models.AutoField(primary_key=True, editable=False)
    name = models.CharField(max_length=200, null=False, blank=False)
    code = models.CharField(max_length=20, null=False, blank=False)
    district = models.CharField(max_length=20, null=False, blank=False)
    township = models.ForeignKey(Township, on_delete=models.CASCADE, null=True, blank=True)
    residents = models.IntegerField(null=False, blank=False)

    def __str__(self):
        return self.name


class Election(models.Model):
    _id = models.AutoField(primary_key=True, editable=False)
    neighbourhoods = models.ManyToManyField(Neighbourhood, through='ElectionNeighbourhood')
    name = models.CharField(max_length=200, null=False, blank=False)
    date = models.DateField(null=False, blank=False)


class Member(models.Model):
    user = models.OneToOneField(User, on_delete=models.CASCADE)
    member = models.CharField(max_length=100)
    neighbourhood = models.ForeignKey(Neighbourhood, on_delete=models.CASCADE, null=True, blank=True)
    registrationDate = models.DateField(null=False, blank=False)
    active = models.BooleanField(null=False, blank=False)

    def __str__(self):
        return self.user.username


class ElectionNeighbourhood(models.Model):
    _id = models.AutoField(primary_key=True, editable=False)
    election = models.ForeignKey(Election, on_delete=models.CASCADE, null=False, related_name='election_to_neighbourhood')
    neighbourhood = models.ForeignKey(Neighbourhood, on_delete=models.CASCADE, null=False, related_name='neighbourhood_to_election')
    responsible = models.ForeignKey(Member, on_delete=models.CASCADE, null=True, blank=True)
    flyer = models.BooleanField(null=False, blank=False)
    status = models.DecimalField(max_digits=3, decimal_places=2, null=False, blank=False)
