from rest_framework import serializers
from rest_framework_simplejwt.serializers import TokenObtainPairSerializer
from .models import *


class MyTokenObtainPairSerializer(TokenObtainPairSerializer):
    def create(self, validated_data):
        pass

    def update(self, instance, validated_data):
        pass

    def validate(self, attrs):
        data = super().validate(attrs)

        data['username'] = self.user.username
        data['email'] = self.user.email
        data['id'] = self.user.id

        return data


class MemberSerializer(serializers.ModelSerializer):
    neighbourhood = serializers.StringRelatedField(many=False)

    class Meta:
        model = Member
        fields = ('member', 'registrationDate', 'active', 'neighbourhood')


class UserDetailsSerializer(serializers.ModelSerializer):
    member = MemberSerializer(many=False)

    class Meta:
        model = User
        fields = ('first_name', 'last_name', 'username', 'member')


class NeighbourhoodSerializer(serializers.ModelSerializer):
    township = serializers.StringRelatedField(many=False)

    class Meta:
        model = Neighbourhood
        fields = ('_id', 'name', 'code', 'district', 'residents', 'township')


class ElectionNeighbourhoodSerializer(serializers.ModelSerializer):
    neighbourhood = NeighbourhoodSerializer(many=False)
    responsible = serializers.StringRelatedField(many=False)

    class Meta:
        model = ElectionNeighbourhood
        fields = ('_id', 'neighbourhood', 'responsible', 'flyer', 'status')


class ElectionSerializer(serializers.ModelSerializer):
    election_to_neighbourhood = ElectionNeighbourhoodSerializer(many=True)

    class Meta:
        model = Election
        fields = ('_id', 'name', 'date', 'election_to_neighbourhood')


class DepartmentSerializer(serializers.ModelSerializer):
    class Meta:
        model = Department
        fields = '__all__'
