from rest_framework import status
from rest_framework.decorators import api_view, permission_classes
from rest_framework.response import Response
from rest_framework.permissions import IsAuthenticated, IsAdminUser
from django.http import JsonResponse
from .serializers import *
from rest_framework_simplejwt.views import TokenObtainPairView


class MyTokenObtainPairView(TokenObtainPairView):
    serializer_class = MyTokenObtainPairSerializer


def getRoutes(request):
    routes = [
        '/api/users/',
        '/api/users/<id>'
    ]
    return JsonResponse(routes, safe=False)


@api_view(['GET'])
@permission_classes([IsAuthenticated])
def getUserDetails(request, pk):
    if request.user.id == pk or request.user.is_staff:
        user = User.objects.get(id=pk)
        serializer = UserDetailsSerializer(user, many=False)
        return Response(serializer.data)
    else:
        return Response()


@api_view(['GET'])
def getDepartments(request):
    departments = Department.objects.all()
    serializer = DepartmentSerializer(departments, many=True)
    return Response(serializer.data)


@api_view(['GET'])
@permission_classes([IsAuthenticated])
def getLatestElection(request):
    election = Election.objects.latest('date')
    serializer = ElectionSerializer(election, many=False)

    return Response(serializer.data)


@api_view(['POST'])
@permission_classes([IsAuthenticated])
def updateNeigbourhoodStatus(request):
    user = request.user
    data = request.data
    if data and len(data) == 0:
        return Response({'detail', 'No data'}, status=status.HTTP_400_BAD_REQUEST)
    else:
        member = Member.objects.get(user=user)
        electionNeighbourhood = ElectionNeighbourhood.objects.get(_id=data['electionNeighbourhoodId'])
        if electionNeighbourhood.responsible == member:
            electionNeighbourhood.status = data['status']
            electionNeighbourhood.save()
            serializer = ElectionNeighbourhoodSerializer(electionNeighbourhood, many=False)
            return Response(serializer.data)
        else:
            return Response({'detail', 'Wrong responsible'}, status=status.HTTP_400_BAD_REQUEST)


@api_view(['POST'])
@permission_classes([IsAuthenticated])
def setNeigbourhoodResponsible(request):
    user = request.user
    data = request.data
    if data and len(data) == 0:
        return Response({'detail', 'No data'}, status=status.HTTP_400_BAD_REQUEST)
    else:
        member = Member.objects.get(user=user)
        electionNeighbourhood = ElectionNeighbourhood.objects.get(_id=data['electionNeighbourhoodId'])
        electionNeighbourhood.responsible = member
        electionNeighbourhood.save()
        serializer = ElectionNeighbourhoodSerializer(electionNeighbourhood, many=False)

        return Response(serializer.data)
